@@ -94,6 +94,9 @@ class TestLoaderProxy:
                                       "TestLoader" % plugin)
 
     def load_plugins(self, config):
+        if self._initialized_plugins:
+            return
+
         def _good_test_types(plugin):
             """
             List all supported test types (excluding incorrect ones)
@@ -145,7 +148,7 @@ class TestLoaderProxy:
 
         # Here is one of the few exceptions that has a hardcoded default
         loaders = config.get("{}.loaders".format(subcommand)) or ['file',
-                                                                '@DEFAULT']
+                                                                  '@DEFAULT']
         if "@DEFAULT" in loaders:  # Replace @DEFAULT with unused loaders
             idx = loaders.index("@DEFAULT")
             loaders = (loaders[:idx] + [plugin for plugin in supported_loaders
@@ -407,7 +410,7 @@ def add_loader_options(parser, section='run'):
                 "settings->plugins.loaders.")
     settings.register_option(section=section,
                              key='loaders',
-                             nargs='*',
+                             nargs='+',
                              key_type=list,
                              default=['file', '@DEFAULT'],
                              help_msg=help_msg,
