@@ -18,32 +18,23 @@
 Conventional Test Runner Plugin
 """
 
+import multiprocessing
 import os
-import time
 import signal
 import sys
-import multiprocessing
+import time
 from queue import Full as queueFullException
 
-
-from avocado.utils import process
-from avocado.utils import stacktrace
-from avocado.utils import wait
-from avocado.core import defaults
-from avocado.core import output
-from avocado.core import status
-from avocado.core import tree
-from avocado.core import varianter
+from avocado.core import output, tree, varianter
 from avocado.core.loader import loader
 from avocado.core.output import LOG_JOB as TEST_LOG
 from avocado.core.output import LOG_UI as APP_LOG
 from avocado.core.plugin_interfaces import Runner
-from avocado.core.runner import add_runner_failure
-from avocado.core.runner import TestStatus
-from avocado.core.settings import settings
-from avocado.core.status import mapping
+from avocado.core.runner import TestStatus, add_runner_failure
 from avocado.core.test import TimeOutSkipTest
 from avocado.core.test_id import TestID
+from avocado.core.teststatus import mapping, user_facing_status
+from avocado.utils import process, stacktrace, wait
 
 
 class TestRunner(Runner):
@@ -57,10 +48,6 @@ class TestRunner(Runner):
 
     DEFAULT_TIMEOUT = 86400
 
-    #: Mode in which this runner should iterate through tests and variants.
-    #: The allowed values are "variants-per-test" or "tests-per-variant"
-    DEFAULT_EXECUTION_ORDER = "variants-per-test"
-
     def __init__(self):
         """
         Creates an instance of TestRunner class.
@@ -68,7 +55,7 @@ class TestRunner(Runner):
         self.sigstopped = False
 
     @staticmethod
-    def _run_test(job, result, test_factory, queue):
+    def _run_test(job, test_factory, queue):
         """
         Run a test instance.
 
@@ -110,9 +97,9 @@ class TestRunner(Runner):
         except queueFullException:
             instance.error(stacktrace.str_unpickable_object(early_state))
 
-        result.start_test(early_state)
+        job.result.start_test(early_state)
         job.result_events_dispatcher.map_method('start_test',
-                                                result,
+                                                job.result,
                                                 early_state)
         if job.config.get('run.log_test_data_directories'):
             data_sources = getattr(instance, "DATA_SOURCES", [])
@@ -135,7 +122,7 @@ class TestRunner(Runner):
             except queueFullException:
                 instance.error(stacktrace.str_unpickable_object(state))
 
-    def run_test(self, job, result, test_factory, queue, summary, job_deadline=0):
+    def run_test(self, job, test_factory, queue, summary, job_deadline=0):
         """
         Run a test instance inside a subprocess.
 
@@ -170,7 +157,7 @@ class TestRunner(Runner):
                     self.sigstopped = True
 
         proc = multiprocessing.Process(target=self._run_test,
-                                       args=(job, result, test_factory, queue,))
+                                       args=(job, test_factory, queue,))
         test_status = TestStatus(job, queue)
 
         cycle_timeout = 1
@@ -247,11 +234,8 @@ class TestRunner(Runner):
 
         # Get/update the test status (decrease timeout on abort)
         if abort_reason:
-            finish_deadline = time.time() + settings.get_value(
-                'runner.timeout',
-                'after_interrupted',
-                key_type=int,
-                default=defaults.TIMEOUT_AFTER_INTERRUPTED)
+            after_interrupted = job.config.get('runner.timeout.after_interrupted')
+            finish_deadline = time.time() + after_interrupted
         else:
             finish_deadline = deadline
         test_state = test_status.finish(proc, time_started, step,
@@ -268,18 +252,18 @@ class TestRunner(Runner):
             job.log.debug('')
 
         # Make sure the test status is correct
-        if test_state.get('status') not in status.user_facing_status:
+        if test_state.get('status') not in user_facing_status:
             test_state = add_runner_failure(test_state, "ERROR", "Test reports"
                                             " unsupported test status.")
 
-        result.check_test(test_state)
-        result_dispatcher.map_method('end_test', result, test_state)
+        job.result.check_test(test_state)
+        result_dispatcher.map_method('end_test', job.result, test_state)
         if test_state['status'] == "INTERRUPTED":
             summary.add("INTERRUPTED")
         elif not mapping[test_state['status']]:
             summary.add("FAIL")
 
-            if job.config.get('run.failfast') == 'on':
+            if job.config.get('run.failfast'):
                 summary.add("INTERRUPTED")
                 job.interrupted_reason = "Interrupting job (failfast)."
                 return False
@@ -329,71 +313,63 @@ class TestRunner(Runner):
                           "variant_id": varianter.generate_variant_id(var),
                           "paths": paths}
 
-    def _iter_suite(self, job, test_suite, variants, execution_order):
+    def _iter_suite(self, test_suite, execution_order):
         """
         Iterates through test_suite and variants in defined order
 
-        :param job: an instance of :class:`avocado.core.job.Job`
-        :param test_suite: a list of tests to run
-        :param variants: a varianter object to produce test params
+        :param test_suite: a TestSuite object to run
         :param execution_order: way of iterating through tests/variants
         :return: generator yielding tuple(test_factory, variant)
         """
         if execution_order == "variants-per-test":
-            return (self._template_to_factory(job.test_parameters,
+            return (self._template_to_factory(test_suite.test_parameters,
                                               template, variant)
-                    for template in test_suite
-                    for variant in variants.itertests())
+                    for template in test_suite.tests
+                    for variant in test_suite.variants.itertests())
         elif execution_order == "tests-per-variant":
-            return (self._template_to_factory(job.test_parameters,
+            return (self._template_to_factory(test_suite.test_parameters,
                                               template, variant)
-                    for variant in variants.itertests()
-                    for template in test_suite)
+                    for variant in test_suite.variants.itertests()
+                    for template in test_suite.tests)
         else:
             raise NotImplementedError("Suite_order %s is not supported"
                                       % execution_order)
 
-    def run_suite(self, job, result, test_suite, variants, timeout=0,
-                  replay_map=None, execution_order=None):
+    def run_suite(self, job, test_suite):
         """
         Run one or more tests and report with test result.
 
         :param job: an instance of :class:`avocado.core.job.Job`.
-        :param result: an instance of :class:`avocado.core.result.Result`
         :param test_suite: a list of tests to run.
-        :param variants: A varianter iterator to produce test params.
-        :param timeout: maximum amount of time (in seconds) to execute.
-        :param replay_map: optional list to override test class based on test
-                           index.
-        :param execution_order: Mode in which we should iterate through tests
-                                and variants.  If not provided, will default to
-                                :attr:`DEFAULT_EXECUTION_ORDER`.
         :return: a set with types of test failures.
         """
         summary = set()
+        replay_map = job.config.get('replay_map')
+        execution_order = job.config.get('run.execution_order')
         queue = multiprocessing.SimpleQueue()
-        if timeout > 0:
-            deadline = time.time() + timeout
+        if job.timeout > 0:
+            deadline = time.time() + job.timeout
         else:
             deadline = None
 
-        test_result_total = variants.get_number_of_tests(test_suite)
+        test_result_total = test_suite.variants.get_number_of_tests(test_suite.tests)
         no_digits = len(str(test_result_total))
-        result.tests_total = test_result_total
+        job.result.tests_total = test_result_total
         index = 1
         try:
-            for test_factory in test_suite:
+            for test_factory in test_suite.tests:
                 test_factory[1]["base_logdir"] = job.logdir
                 test_factory[1]["job"] = job
-            if execution_order is None:
-                execution_order = self.DEFAULT_EXECUTION_ORDER
-            for test_factory, variant in self._iter_suite(job,
-                                                          test_suite,
-                                                          variants,
+            for test_factory, variant in self._iter_suite(test_suite,
                                                           execution_order):
                 test_parameters = test_factory[1]
                 name = test_parameters.get("name")
-                test_parameters["name"] = TestID(index, name,
+                if test_suite.name:
+                    prefix = "{}-{}".format(test_suite.name, index)
+                else:
+                    prefix = index
+                test_parameters["name"] = TestID(prefix,
+                                                 name,
                                                  variant,
                                                  no_digits)
                 if deadline is not None and time.time() > deadline:
@@ -401,15 +377,13 @@ class TestRunner(Runner):
                     if 'methodName' in test_parameters:
                         del test_parameters['methodName']
                     test_factory = (TimeOutSkipTest, test_parameters)
-                    if not self.run_test(job, result, test_factory, queue, summary):
+                    if not self.run_test(job, test_factory, queue, summary):
                         break
                 else:
                     if (replay_map is not None and
                             replay_map[index - 1] is not None):
-                        test_parameters["methodName"] = "test"
-                        test_factory = (replay_map[index], test_parameters)
-
-                    if not self.run_test(job, result, test_factory, queue, summary,
+                        test_factory = (replay_map[index - 1], test_parameters)
+                    if not self.run_test(job, test_factory, queue, summary,
                                          deadline):
                         break
                 index += 1
@@ -417,7 +391,7 @@ class TestRunner(Runner):
             TEST_LOG.error('Job interrupted by ctrl+c.')
             summary.add('INTERRUPTED')
 
-        result.end_tests()
+        job.result.end_tests()
         job.funcatexit.run()
         signal.signal(signal.SIGTSTP, signal.SIG_IGN)
         return summary
