@@ -33,8 +33,6 @@ except ImportError:
     AEXPECT_CAPABLE = False
 
 
-
-
 UNSUPPORTED_STATUS_TEST_CONTENTS = '''
 from avocado import Test
 
@@ -198,7 +196,7 @@ class RunnerOperationTest(TestCaseTmpDir):
         process.run(cmd_line)
         # Also check whether jobdata contains correct parameter paths
         variants = open(os.path.join(self.tmpdir.name, "latest", "jobdata",
-                        "variants.json")).read()
+                                     "variants.json")).read()
         self.assertIn('["/run/*"]', variants, "paths stored in jobdata "
                       "does not contains [\"/run/*\"]\n%s" % variants)
 
@@ -455,8 +453,8 @@ class RunnerOperationTest(TestCaseTmpDir):
                       result.stderr)
 
     def test_empty_test_list(self):
-        cmd_line = '%s run --disable-sysinfo --job-results-dir %s' % (AVOCADO,
-                                                                  self.tmpdir.name)
+        cmd_line = '%s run --disable-sysinfo --job-results-dir %s' \
+                   % (AVOCADO, self.tmpdir.name)
         result = process.run(cmd_line, ignore_status=True)
         self.assertEqual(result.exit_status, exit_codes.AVOCADO_JOB_FAIL)
         self.assertIn(b'No test references provided nor any other arguments '
@@ -944,7 +942,6 @@ class RunnerSimpleTestStatus(TestCaseTmpDir):
         self.config_file.remove()
 
 
-
 class ExternalRunnerTest(TestCaseTmpDir):
 
     def setUp(self):
