@@ -3,14 +3,12 @@ import stat
 import tempfile
 import unittest.mock
 
-from avocado.core import test
+from avocado.core import loader, test
 from avocado.core.test_id import TestID
-from avocado.core import loader
 from avocado.utils import script
 
 from .. import setup_avocado_loggers, temp_dir_prefix
 
-
 setup_avocado_loggers()
 
 
@@ -269,7 +267,7 @@ class LoaderTest(unittest.TestCase):
                                      ':MultipleMethods.testTwo', loader.DiscoverMode.ALL)
         self.assertEqual(len(suite), 1)
         self.assertEqual(suite[0][1]["methodName"], 'testTwo')
-        # Load using regexp
+        # Load using regex
         suite = self.loader.discover(avocado_multiple_tests.path +
                                      ':.*_one', loader.DiscoverMode.ALL)
         self.assertEqual(len(suite), 1)
